// metaRoutes.js

function metaRoutes(app, { version, config, isServiceReady, metricsEndpoint }, routeOptions = {}) {
  // Default options with all routes enabled
  const defaults = {
    enableVersion: true,
    enableConfig: true,
    enableHealth: true,
    enableReady: true,
    enableMetrics: true,
  };

  // Merge user provided options with defaults
  const options = { ...defaults, ...routeOptions };

  if (options.enableVersion) {
    app.get('/_version', function (req, res) {
      res.send(version);
    });
  }

  if (options.enableConfig) {
    app.get('/_config', function (req, res) {
      res.send(config._show());
    });
  }

  if (options.enableHealth) {
    app.get('/_health', function (req, res) {
      res.send('OK');
    });
  }

  if (options.enableReady) {
    app.get('/_ready', function (req, res) {
      if (isServiceReady()) {
        res.send('OK');
      } else {
        res.status(503).send('Not ready');
      }
    });
  }

  if (options.enableMetrics) {
    app.get('/_metrics', metricsEndpoint);
  }
}

module.exports = metaRoutes;
